@@ -20,8 +20,9 @@ head(lsting, 15)
 
 ## -----------------------------------------------------------------------------
 lsting <- as_listing(
-    df = adae,
-    non_disp_cols = tail(names(adae), 8))
+  df = adae,
+  non_disp_cols = tail(names(adae), 8)
+)
 head(lsting, 15)
 
 ## -----------------------------------------------------------------------------
